@@ -4,18 +4,14 @@ import optparse
 import os
 import re
 import sys
-import termios
 import ConfigParser
 
 from ConfigParser import NoSectionError, NoOptionError
-from functools import partial
 from getpass import getpass
 
 from yoyo.migrate.connections import connect, parse_uri, unparse_uri
 from yoyo.migrate.utils import prompt, plural
-from yoyo.migrate import Migration, MigrationStep
-from yoyo.migrate import DatabaseError
-from yoyo.migrate import read_migrations, create_migrations_table
+from yoyo.migrate import read_migrations
 from yoyo.migrate import logger
 
 verbosity_levels = {
